@@ -11,16 +11,15 @@ require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(path to_path);
 
-# Directory separator
-my $separator;
-# Regular expression that matches directory separators
-my $separator_re;
+# Mapping between package names and regular expressions that match directory
+# separators
+my %separator_re;
 
 
 sub path {
     my @paths = @_;
-    
-    my @path_components = map { split($separator_re, $_) } @paths;
+    my @path_components = map { split($separator_re{caller()} ||= '/', $_) }
+        @paths;
     return File::Spec->catfile(@path_components);
 }
 
@@ -29,13 +28,10 @@ sub path {
 
 
 sub set_separator {
-    $separator = quotemeta(shift);
-    $separator_re = qr{$separator};
+    my $separator = quotemeta(shift);
+    $separator_re{caller()} = qr{$separator};
 }
 
-# Set forward slash as the default directory separator
-set_separator('/');
-
 
 1;
 
@@ -48,7 +44,7 @@ File::PlainPath - Construct portable filesystem paths in a simple way
 
 =head1 VERSION
 
-version 0.011
+version 0.02
 
 =head1 SYNOPSIS
 
